@@ -143,9 +143,11 @@ set_operators = [
 ]
 
 type_convertion_operators = [
+    '$convert',
     '$toString',
     '$toInt',
     '$toDecimal',
+    '$toLong',
     '$arrayToObject'
 ]
 
@@ -542,6 +544,19 @@ class _Parser(object):
             ' in Mongomock.' % operator)
 
     def _handle_array_operator(self, operator, value):
+        if operator == '$concatArrays':
+            if not isinstance(value, (list, tuple)):
+                value = [value]
+
+            parsed_list = list(self.parse_many(value))
+            for parsed_item in parsed_list:
+                if parsed_item is not None and not isinstance(parsed_item, (list, tuple)):
+                    raise OperationFailure(
+                        '$concatArrays only supports arrays, not {}'.format(type(parsed_item))
+                    )
+
+            return None if None in parsed_list else list(itertools.chain.from_iterable(parsed_list))
+
         if operator == '$size':
             if isinstance(value, list):
                 if len(value) != 1:
@@ -700,6 +715,11 @@ class _Parser(object):
                 'with k and v fields or two-element arrays'
             )
 
+        raise NotImplementedError(
+            "Although '%s' is a valid type conversion operator for the "
+            'aggregation pipeline, it is currently not implemented '
+            'in Mongomock.' % operator)
+
     def _handle_conditional_operator(self, operator, values):
         if operator == '$ifNull':
             field, fallback = values
