@@ -399,6 +399,11 @@ class Collection(object):
                 (self.__class__.__name__, attr, self.name, attr, self.name, attr))
         return self.__getitem__(attr)
 
+    def __eq__(self, other):
+        if isinstance(other, self.__class__):
+            return self.database == other.database and self.name == other.name
+        return NotImplemented
+
     @property
     def full_name(self):
         return '{0}.{1}'.format(self.database.name, self._name)
@@ -549,20 +554,23 @@ class Collection(object):
 
     def update_one(
             self, filter, update, upsert=False, bypass_document_validation=False, hint=None,
-            session=None):
+            session=None, collation=None):
         if not bypass_document_validation:
             validate_ok_for_update(update)
         return UpdateResult(
-            self._update(filter, update, upsert=upsert, hint=hint, session=session),
+            self._update(
+                filter, update, upsert=upsert, hint=hint, session=session, collation=collation),
             acknowledged=True)
 
     def update_many(
             self, filter, update, upsert=False, bypass_document_validation=False, hint=None,
-            session=None):
+            session=None, collation=None):
         if not bypass_document_validation:
             validate_ok_for_update(update)
         return UpdateResult(
-            self._update(filter, update, upsert=upsert, multi=True, hint=hint, session=session),
+            self._update(
+                filter, update, upsert=upsert, multi=True, hint=hint, session=session,
+                collation=collation),
             acknowledged=True)
 
     def replace_one(
@@ -582,13 +590,19 @@ class Collection(object):
                             check_keys, **kwargs)
 
     def _update(self, spec, document, upsert=False, manipulate=False,
-                multi=False, check_keys=False, hint=None, session=None, **kwargs):
+                multi=False, check_keys=False, hint=None, session=None,
+                collation=None, **kwargs):
         if session:
             raise_not_implemented('session', 'Mongomock does not handle sessions yet')
         if hint:
             raise NotImplementedError(
                 'The hint argument of update is valid but has not been implemented in '
                 'mongomock yet')
+        if collation:
+            raise_not_implemented(
+                'collation',
+                'The collation argument of update is valid but has not been implemented in '
+                'mongomock yet')
         spec = helpers.patch_datetime_awareness_in_document(spec)
         document = helpers.patch_datetime_awareness_in_document(document)
         validate_is_mapping('spec', spec)
@@ -1826,7 +1840,7 @@ class Cursor(object):
         if with_limit_and_skip:
             results = self._results[self._skip:]
             if self._limit:
-                results = results[:self._limit]
+                results = results[:abs(self._limit)]
         else:
             results = self._results
         return results
@@ -1953,6 +1967,10 @@ class Cursor(object):
     def alive(self):
         return self._emitted != self.count()
 
+    @property
+    def collation(self):
+        return self._collation
+
     def max_time_ms(self, max_time_ms):
         if max_time_ms is not None and not isinstance(max_time_ms, int):
             raise TypeError('max_time_ms must be an integer or None')
